@@ -44,7 +44,7 @@ import (
 	minteraws "github.com/openshift/cloud-credential-operator/pkg/aws"
 	"github.com/openshift/cloud-credential-operator/pkg/aws/actuator"
 	mockaws "github.com/openshift/cloud-credential-operator/pkg/aws/mock"
-	"github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator"
+	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -784,6 +784,55 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 				assert.NotEqual(t, testTwentyMinuteOldTimestamp.Unix(), cr.Status.LastSyncTimestamp.Time.Unix())
 			},
 		},
+		{
+			name: "skip nonAWS credreq",
+			existing: []runtime.Object{
+				testGCPCredentialsRequest(t),
+			},
+			mockRootAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				return mockaws.NewMockClient(mockCtrl)
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cr := getCR(c)
+				assert.False(t, cr.Status.Provisioned, "CRs for wrong cloud should be unprovisioned")
+			},
+			expectedConditions: []ExpectedCondition{
+				{
+					conditionType: minterv1.Ignored,
+					reason:        "InfrastructureMismatch",
+					status:        corev1.ConditionTrue,
+				},
+			},
+		},
+		{
+			name: "clear conditions when ignoring cred request",
+			existing: []runtime.Object{
+				func() runtime.Object {
+					cr := testGCPCredentialsRequest(t)
+					for _, cond := range failureConditionTypes {
+						cr.Status.Conditions = append(cr.Status.Conditions, minterv1.CredentialsRequestCondition{
+							Type:   cond,
+							Status: corev1.ConditionTrue,
+						})
+					}
+
+					return cr
+				}(),
+			},
+			mockRootAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				return mockaws.NewMockClient(mockCtrl)
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cr := getCR(c)
+
+				// verify all the other conditions that would put CCO in a failed state are cleared
+				for _, cond := range cr.Status.Conditions {
+					if cond.Type != minterv1.Ignored {
+						assert.Equal(t, corev1.ConditionFalse, cond.Status, "ignored CR should have other condition cleared")
+					}
+				}
+			},
+		},
 		{
 			name: "pass along any existing permissions boundary",
 			existing: []runtime.Object{
@@ -861,6 +910,7 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 						}
 					},
 				},
+				platformType: configv1.AWSPlatformType,
 			}
 
 			_, err = rcr.Reconcile(reconcile.Request{
@@ -967,6 +1017,9 @@ func testPassthroughCredentialsRequest(t *testing.T) *minterv1.CredentialsReques
 	}
 	awsProvSpec, err := codec.EncodeProviderSpec(
 		&minterv1.AWSProviderSpec{
+			TypeMeta: metav1.TypeMeta{
+				Kind: "AWSProviderSpec",
+			},
 			StatementEntries: []minterv1.StatementEntry{
 				{
 					Effect: "Allow",
@@ -1035,13 +1088,13 @@ func createTestNamespace(namespace string) *corev1.Namespace {
 
 func testInsufficientAWSCredsSecret(namespace, name, accessKeyID, secretAccessKey string) *corev1.Secret {
 	s := testAWSCredsSecret(namespace, name, accessKeyID, secretAccessKey)
-	s.Annotations[secretannotator.AnnotationKey] = secretannotator.InsufficientAnnotation
+	s.Annotations[annotatorconst.AnnotationKey] = annotatorconst.InsufficientAnnotation
 	return s
 }
 
 func testPassthroughAWSCredsSecret(namespace, name, accessKeyID, secretAccessKey string) *corev1.Secret {
 	s := testAWSCredsSecret(namespace, name, accessKeyID, secretAccessKey)
-	s.Annotations[secretannotator.AnnotationKey] = secretannotator.PassthroughAnnotation
+	s.Annotations[annotatorconst.AnnotationKey] = annotatorconst.PassthroughAnnotation
 	return s
 }
 
@@ -1051,7 +1104,7 @@ func testAWSCredsSecret(namespace, name, accessKeyID, secretAccessKey string) *c
 			Name:      name,
 			Namespace: namespace,
 			Annotations: map[string]string{
-				secretannotator.AnnotationKey: secretannotator.MintAnnotation,
+				annotatorconst.AnnotationKey: annotatorconst.MintAnnotation,
 			},
 		},
 		Data: map[string][]byte{
