@@ -33,6 +33,16 @@ const (
 	reasonCredentialsNotProvisioned = "CredentialsNotProvisioned"
 )
 
+var (
+	// If any of these conditions are present and true, we consider it a failing credential:
+	failureConditionTypes = []minterv1.CredentialsRequestConditionType{
+		minterv1.InsufficientCloudCredentials,
+		minterv1.MissingTargetNamespace,
+		minterv1.CredentialsProvisionFailure,
+		minterv1.CredentialsDeprovisionFailure,
+	}
+)
+
 // syncOperatorStatus computes the operator's current status and
 // creates or updates the ClusterOperator resource for the operator accordingly.
 func (r *ReconcileCredentialsRequest) syncOperatorStatus() error {
@@ -51,8 +61,10 @@ func (r *ReconcileCredentialsRequest) syncOperatorStatus() error {
 
 	oldConditions := co.Status.Conditions
 	oldVersions := co.Status.Versions
-	co.Status.Conditions = computeStatusConditions(oldConditions, credRequests)
+	oldRelatedObjects := co.Status.RelatedObjects
+	co.Status.Conditions = computeStatusConditions(oldConditions, credRequests, r.platformType)
 	co.Status.Versions = computeClusterOperatorVersions()
+	co.Status.RelatedObjects = buildExpectedRelatedObjects(credRequests)
 
 	// ClusterOperator should already exist (from the manifests payload), but recreate it if needed
 	if isNotFound {
@@ -74,7 +86,10 @@ func (r *ReconcileCredentialsRequest) syncOperatorStatus() error {
 	}
 
 	// Update status fields if needed
-	if !clusteroperator.ConditionsEqual(oldConditions, co.Status.Conditions) || !reflect.DeepEqual(oldVersions, co.Status.Versions) {
+	if !clusteroperator.ConditionsEqual(oldConditions, co.Status.Conditions) ||
+		!reflect.DeepEqual(oldVersions, co.Status.Versions) ||
+		!reflect.DeepEqual(oldRelatedObjects, co.Status.RelatedObjects) {
+
 		err = r.Client.Status().Update(context.TODO(), co)
 		if err != nil {
 			return fmt.Errorf("failed to update clusteroperator %s: %v", co.Name, err)
@@ -103,7 +118,7 @@ func (r *ReconcileCredentialsRequest) getOperatorState() (*corev1.Namespace, []m
 	// central list to live. Other credentials requests in other namespaces will not affect status,
 	// but they will still work fine.
 	credRequestList := &minterv1.CredentialsRequestList{}
-	err := r.Client.List(context.TODO(), &client.ListOptions{Namespace: minterv1.CloudCredOperatorNamespace}, credRequestList)
+	err := r.Client.List(context.TODO(), credRequestList, client.InNamespace(minterv1.CloudCredOperatorNamespace))
 	if err != nil {
 		return nil, nil, fmt.Errorf(
 			"failed to list CredentialsRequests: %v", err)
@@ -124,7 +139,7 @@ func computeClusterOperatorVersions() []configv1.OperandVersion {
 }
 
 // computeStatusConditions computes the operator's current state.
-func computeStatusConditions(conditions []configv1.ClusterOperatorStatusCondition, credRequests []minterv1.CredentialsRequest) []configv1.ClusterOperatorStatusCondition {
+func computeStatusConditions(conditions []configv1.ClusterOperatorStatusCondition, credRequests []minterv1.CredentialsRequest, clusterCloudPlatform configv1.PlatformType) []configv1.ClusterOperatorStatusCondition {
 
 	// Degraded should be true if we are encountering errors. We consider any credentials request
 	// with either provision or deprovision failure conditions true, to be a degraded condition.
@@ -133,16 +148,24 @@ func computeStatusConditions(conditions []configv1.ClusterOperatorStatusConditio
 		Status: configv1.ConditionFalse,
 	}
 
-	// If any of these conditions are present and true, we consider it a failing credential:
-	failureConditionTypes := []minterv1.CredentialsRequestConditionType{
-		minterv1.InsufficientCloudCredentials,
-		minterv1.MissingTargetNamespace,
-		minterv1.CredentialsProvisionFailure,
-		minterv1.CredentialsDeprovisionFailure,
-	}
 	failingCredRequests := 0
 
-	for _, cr := range credRequests {
+	validCredRequests := []minterv1.CredentialsRequest{}
+	// Filter out credRequests that are for different clouds
+	for i, cr := range credRequests {
+		infraMatches, err := crInfraMatches(&cr, clusterCloudPlatform)
+		if err != nil {
+			// couldn't decode the providerspec (bad spec data?)
+			log.WithField("credentialsRequest", cr.Name).WithError(err).Warning("ignoring for status condition because could not decode provider spec")
+			continue
+		}
+		if !infraMatches {
+			continue
+		}
+		validCredRequests = append(validCredRequests, credRequests[i])
+	}
+
+	for _, cr := range validCredRequests {
 		// Check for provision failure conditions:
 		foundFailure := false
 		for _, t := range failureConditionTypes {
@@ -164,7 +187,7 @@ func computeStatusConditions(conditions []configv1.ClusterOperatorStatusConditio
 		degradedCondition.Reason = reasonCredentialsFailing
 		degradedCondition.Message = fmt.Sprintf(
 			"%d of %d credentials requests are failing to sync.",
-			failingCredRequests, len(credRequests))
+			failingCredRequests, len(validCredRequests))
 	} else {
 		degradedCondition.Status = configv1.ConditionFalse
 		degradedCondition.Reason = reasonNoCredentialsFailing
@@ -182,9 +205,9 @@ func computeStatusConditions(conditions []configv1.ClusterOperatorStatusConditio
 		Status: configv1.ConditionUnknown,
 	}
 	credRequestsNotProvisioned := 0
-	log.Debugf("%d cred requests", len(credRequests))
+	log.Debugf("%d cred requests", len(validCredRequests))
 
-	for _, cr := range credRequests {
+	for _, cr := range validCredRequests {
 		if !cr.Status.Provisioned {
 			credRequestsNotProvisioned = credRequestsNotProvisioned + 1
 		}
@@ -194,13 +217,13 @@ func computeStatusConditions(conditions []configv1.ClusterOperatorStatusConditio
 		progressingCondition.Reason = reasonReconciling
 		progressingCondition.Message = fmt.Sprintf(
 			"%d of %d credentials requests provisioned, %d reporting errors.",
-			len(credRequests)-credRequestsNotProvisioned, len(credRequests), failingCredRequests)
+			len(validCredRequests)-credRequestsNotProvisioned, len(validCredRequests), failingCredRequests)
 	} else {
 		progressingCondition.Status = configv1.ConditionFalse
 		progressingCondition.Reason = reasonReconcilingComplete
 		progressingCondition.Message = fmt.Sprintf(
 			"%d of %d credentials requests provisioned and reconciled.",
-			len(credRequests), len(credRequests))
+			len(validCredRequests), len(validCredRequests))
 	}
 	conditions = clusteroperator.SetStatusCondition(conditions,
 		progressingCondition)
@@ -217,6 +240,15 @@ func computeStatusConditions(conditions []configv1.ClusterOperatorStatusConditio
 	conditions = clusteroperator.SetStatusCondition(conditions,
 		availableCondition)
 
+	// CCO doesn't have the idea of upgradeable vs not-upgradeable, but should report that condition nevertheless.
+	// Always be upgradeable.
+	upgradeableCondition := &configv1.ClusterOperatorStatusCondition{
+		Status: configv1.ConditionTrue,
+		Type:   configv1.OperatorUpgradeable,
+	}
+	conditions = clusteroperator.SetStatusCondition(conditions,
+		upgradeableCondition)
+
 	// Log all conditions we set:
 	for _, c := range conditions {
 		log.WithFields(log.Fields{
@@ -240,3 +272,24 @@ func findClusterOperatorCondition(conditions []configv1.ClusterOperatorStatusCon
 	}
 	return nil
 }
+
+// buildExpectedRelatedObjects returns the list of expected related objects, used
+// by the oc must-gather command to fetch resource yaml for debugging purposes.
+// Keeping this up to date across versions via the code seems like the safest option.
+func buildExpectedRelatedObjects(credRequests []minterv1.CredentialsRequest) []configv1.ObjectReference {
+	related := []configv1.ObjectReference{
+		{
+			Resource: "namespaces",
+			Name:     cloudCredOperatorNamespace,
+		},
+	}
+	for _, cr := range credRequests {
+		related = append(related, configv1.ObjectReference{
+			Group:     minterv1.SchemeGroupVersion.Group,
+			Resource:  "CredentialsRequest",
+			Namespace: cr.Namespace,
+			Name:      cr.Name,
+		})
+	}
+	return related
+}
